@@ -14,13 +14,13 @@ Acme::CPANAuthors::You::re_using - We are the CPAN authors that have written the
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
 our $VERSION;
 BEGIN {
- $VERSION = '0.07';
+ $VERSION = '0.08';
 }
 
 =head1 SYNOPSIS
@@ -101,7 +101,11 @@ BEGIN { register() }
 
 =head1 DEPENDENCIES
 
-L<File::Find>, L<Module::Metadata>, L<Acme::CPANAuthors>.
+L<File::Find> (core since perl 5)
+
+L<Acme::CPANAuthors> 0.16.
+
+L<Module::Metadata> 1.000_017.
 
 =head1 SEE ALSO
 
